@@ -10,7 +10,7 @@ from rest_framework import serializers
 from rest_framework.fields import SkipField
 from parler.models import TranslatableModelMixin, TranslatedFieldsModel
 from parler.utils.context import switch_language
-from parler_rest.utils import create_translated_fields_serializer
+from orion_common.orion_core.utils import create_translated_fields_serializer
 
 
 class TranslatedFieldsField(serializers.Field):
